# dddpy
[![CI](https://github.com/aeroworks-io/dddpy/workflows/CI/badge.svg)](https://github.com/aeroworks-io/dddpy/actions?query=workflow%3ACI)  
[![codecov](https://codecov.io/gh/aeroworks-io/dddpy/branch/main/graph/badge.svg?token=BOO43Q8GIF)](https://codecov.io/gh/aeroworks-io/dddpy)
[![PyPI version](https://badge.fury.io/py/dddpy.svg)](https://badge.fury.io/py/dddpy)

A Framework to support ddd python projects
